"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.JsonpackContentCompressionPlugin = void 0;
var _jsonpack = _interopRequireDefault(require("jsonpack"));
var _ContentCompressionPlugin = require("./ContentCompressionPlugin");
const JSONPACK_COMPRESSION = "jsonpack";

/**
 * The default compression plugin for the page content field.
 */
class JsonpackContentCompressionPlugin extends _ContentCompressionPlugin.ContentCompressionPlugin {
  constructor() {
    super(JSONPACK_COMPRESSION);
  }
  canCompress() {
    return false;
  }
  canDecompress(value) {
    if (!value || !value.compression) {
      return false;
    }
    return value.compression === JSONPACK_COMPRESSION;
  }
  async compress(value) {
    if (!value) {
      return {
        compression: JSONPACK_COMPRESSION,
        content: null
      };
    }
    let compressed = null;
    try {
      compressed = _jsonpack.default.pack(value);
    } catch (ex) {
      console.log(`Error while compressing page content: ${ex.message}`);
    }
    return {
      compression: JSONPACK_COMPRESSION,
      content: compressed
    };
  }
  async decompress(value) {
    if (!value || !value.content) {
      return null;
    }
    try {
      return _jsonpack.default.unpack(value.content);
    } catch (ex) {
      console.log(`Error while decompressing page content: ${ex.message}`);
      return null;
    }
  }
}
exports.JsonpackContentCompressionPlugin = JsonpackContentCompressionPlugin;

//# sourceMappingURL=JsonpackContentCompressionPlugin.js.map