"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SaveTranslatableCollectionUseCase = void 0;
var _UpdateTranslatableCollectionRepository = require("../repository/UpdateTranslatableCollectionRepository");
var _GetOrCreateTranslatableCollectionUseCase = require("./GetOrCreateTranslatableCollectionUseCase");
var _CreateTranslatableCollectionRepository = require("../repository/CreateTranslatableCollectionRepository");
var _Identifier = require("../../Identifier");
var _TranslatableItem = require("../domain/TranslatableItem");
class SaveTranslatableCollectionUseCase {
  constructor(context) {
    this.context = context;
  }
  async execute(params) {
    const getOrCreate = new _GetOrCreateTranslatableCollectionUseCase.GetOrCreateTranslatableCollectionUseCase(this.context);
    const collection = await getOrCreate.execute(params.collectionId);
    const identity = this.getIdentity();
    const items = params.items.map(item => {
      return _TranslatableItem.TranslatableItem.create({
        itemId: item.itemId,
        value: item.value,
        context: item.context,
        modifiedOn: item.modifiedOn ? new Date(item.modifiedOn) : new Date(),
        modifiedBy: identity
      });
    });
    collection.setItems(items);
    if (collection.getId()) {
      const update = new _UpdateTranslatableCollectionRepository.UpdateTranslatableCollectionRepository(this.context);
      await update.execute(collection);
    } else {
      collection.setId(_Identifier.Identifier.generate());
      const create = new _CreateTranslatableCollectionRepository.CreateTranslatableCollectionRepository(this.context);
      await create.execute(collection);
    }
    return collection;
  }
  getIdentity() {
    const identity = this.context.security.getIdentity();
    return {
      id: identity.id,
      type: identity.type,
      displayName: identity.displayName || ""
    };
  }
}
exports.SaveTranslatableCollectionUseCase = SaveTranslatableCollectionUseCase;

//# sourceMappingURL=SaveTranslatableCollectionUseCase.js.map